==> angular.js_1.2.16-1.debian.tar.xz: debian/smash-angularSrc.js <==
import "src/minErr.js";
import "src/Angular.js";
import "src/loader.js";
import "src/AngularPublic.js";
import "src/jqLite.js";
import "src/apis.js";
import "src/auto/injector.js";
import "src/ng/anchorScroll.js";
import "src/ng/animate.js";
import "src/ng/asyncCallback.js";
import "src/ng/browser.js";
import "src/ng/cacheFactory.js";
import "src/ng/compile.js";
import "src/ng/controller.js";
import "src/ng/document.js";
import "src/ng/exceptionHandler.js";
import "src/ng/http.js";
import "src/ng/httpBackend.js";
import "src/ng/interpolate.js";
import "src/ng/interval.js";
import "src/ng/locale.js";
import "src/ng/location.js";
import "src/ng/log.js";
import "src/ng/parse.js";
import "src/ng/q.js";
import "src/ng/raf.js";
import "src/ng/rootScope.js";
import "src/ng/sanitizeUri.js";
import "src/ng/sce.js";
import "src/ng/sniffer.js";
import "src/ng/timeout.js";
import "src/ng/urlUtils.js";
import "src/ng/window.js";
import "src/ng/filter.js";
import "src/ng/filter/filter.js";
import "src/ng/filter/filters.js";
import "src/ng/filter/limitTo.js";
import "src/ng/filter/orderBy.js";
import "src/ng/directive/directives.js";
import "src/ng/directive/a.js";
import "src/ng/directive/booleanAttrs.js";
import "src/ng/directive/form.js";
import "src/ng/directive/input.js";
import "src/ng/directive/ngBind.js";
import "src/ng/directive/ngClass.js";
import "src/ng/directive/ngCloak.js";
import "src/ng/directive/ngController.js";
import "src/ng/directive/ngCsp.js";
import "src/ng/directive/ngEventDirs.js";
import "src/ng/directive/ngIf.js";
import "src/ng/directive/ngInclude.js";
import "src/ng/directive/ngInit.js";
import "src/ng/directive/ngNonBindable.js";
import "src/ng/directive/ngPluralize.js";
import "src/ng/directive/ngRepeat.js";
import "src/ng/directive/ngShowHide.js";
import "src/ng/directive/ngStyle.js";
import "src/ng/directive/ngSwitch.js";
import "src/ng/directive/ngTransclude.js";
import "src/ng/directive/script.js";
import "src/ng/directive/select.js";
import "src/ng/directive/style.js";

==> angular.js_1.3.13-1.debian.tar.xz: debian/smash-angularSrc.js <==
import "src/minErr.js";
import "src/Angular.js";
import "src/loader.js";
import "src/stringify.js";
import "src/AngularPublic.js";
import "src/jqLite.js";
import "src/apis.js";
import "src/auto/injector.js";
import "src/ng/anchorScroll.js";
import "src/ng/animate.js";
import "src/ng/asyncCallback.js";
import "src/ng/browser.js";
import "src/ng/cacheFactory.js";
import "src/ng/compile.js";
import "src/ng/controller.js";
import "src/ng/document.js";
import "src/ng/exceptionHandler.js";
import "src/ng/http.js";
import "src/ng/httpBackend.js";
import "src/ng/interpolate.js";
import "src/ng/interval.js";
import "src/ng/locale.js";
import "src/ng/location.js";
import "src/ng/log.js";
import "src/ng/parse.js";
import "src/ng/q.js";
import "src/ng/raf.js";
import "src/ng/rootScope.js";
import "src/ng/sanitizeUri.js";
import "src/ng/sce.js";
import "src/ng/sniffer.js";
import "src/ng/templateRequest.js";
import "src/ng/testability.js";
import "src/ng/timeout.js";
import "src/ng/urlUtils.js";
import "src/ng/window.js";
import "src/ng/filter.js";
import "src/ng/filter/filter.js";
import "src/ng/filter/filters.js";
import "src/ng/filter/limitTo.js";
import "src/ng/filter/orderBy.js";
import "src/ng/directive/directives.js";
import "src/ng/directive/a.js";
import "src/ng/directive/attrs.js";
import "src/ng/directive/form.js";
import "src/ng/directive/input.js";
import "src/ng/directive/ngBind.js";
import "src/ng/directive/ngChange.js";
import "src/ng/directive/ngClass.js";
import "src/ng/directive/ngCloak.js";
import "src/ng/directive/ngController.js";
import "src/ng/directive/ngCsp.js";
import "src/ng/directive/ngEventDirs.js";
import "src/ng/directive/ngIf.js";
import "src/ng/directive/ngInclude.js";
import "src/ng/directive/ngInit.js";
import "src/ng/directive/ngList.js";
import "src/ng/directive/ngModel.js";
import "src/ng/directive/ngNonBindable.js";
import "src/ng/directive/ngPluralize.js";
import "src/ng/directive/ngRepeat.js";
import "src/ng/directive/ngShowHide.js";
import "src/ng/directive/ngStyle.js";
import "src/ng/directive/ngSwitch.js";
import "src/ng/directive/ngTransclude.js";
import "src/ng/directive/script.js";
import "src/ng/directive/select.js";
import "src/ng/directive/style.js";
import "src/ng/directive/validators.js";
